==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_vi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="vi" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Tiện ích %1 không tương thích với hệ thống</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Cài đặt Blurtooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Tắt</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Mở</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Cài đặt Blurtooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 đã kết nối</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Đang kết nối...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Đã tắt</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Thêm bố cục bàn phím</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Ngày giờ</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>Chế độ 12 giờ</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>Chế độ 24 giờ</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Cài đặt thời gian</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>Cho phép mạng</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Vô hiệu hóa mạng</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Thiết lập mạng</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Bạn có chắc chắn muốn làm trống mục %1 không?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Hủy</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Xóa</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Hành động này không thể được phục hồi</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Thiết bị không xác định</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Âm lượng không xác định</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Đĩa</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Mở</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Tháo tất cả</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Khởi chạy</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Chế độ Thời trang</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Chế độ Hiệu quả</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Trên đỉnh</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Dưới đáy</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Trái</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Phải</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Tiếp tục Hiển thị</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Tiếp tục Ẩn</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Ẩn Thông minh</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Chế độ</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Nơi chốn</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Tình trạng</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Các phần bổ sung</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Chế độ xem đa nhiệm</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Gỡ khỏi dock</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Tắt kết nối mạng dây</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Mở kết nối mạng dây</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Tắt kết nối wifi</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Bật kết nối wifi</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Vô hiệu hóa mạng</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Cho phép mạng</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Thiết lập mạng</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>Thiết bị bị vô hiệu hóa</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>Kết nối không dây: %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>Kết nối Có dây: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Không được kết nối</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Đang kết nối</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Đã kết nối nhưng không có truy cập Internet</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Mạng dây đã ngắt</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Mạng không dây</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Mạng kết nối dây</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Mạng</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Mạng kết nối dây</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Mạng kết nối dây %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Cài đặt</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Năng lượng</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Thiết lập năng lượng</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Năng lượng %1, %2 còn lại</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Năng lượng %1, %2 giờ %3 phút còn lại</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Đang sạc %1, %2 phút sẽ đầy</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Đang sạc %1, %2 giờ %3 phút sẽ đầy</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>Được sạt</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Phù hợp %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Đang nạp %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Công suất 1%...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Công suất 1%, sạc đã đầy</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Hiện Trang chính</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Gỡ khỏi dock</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Năng lượng</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Tắt máy</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Dừng</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Ngủ đông</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Khóa</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Thoát ra</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Đổi tài khoản</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Thiết lập năng lượng</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Khởi động lại</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Thiết bị</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Mở tiếng</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Câm</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Cài đặt âm thanh</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Âm lượng %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Âm thanh</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Rác</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Rác - %1 tập tin</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Rác - %1 tập tin</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Mở</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Làm sạch</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>Khay Hệ thống</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>Mạng không dây</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Mạng Không dây %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.53.orig.tar.xz: dde-dock-5.5.53/translations/dde-dock_vi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="vi">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Tiện ích %1 không tương thích với hệ thống</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Tắt</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Mở</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Cài đặt Blurtooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Tắt</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Mở</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Cài đặt Blurtooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 đã kết nối</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Đang kết nối...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Đã tắt</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Thêm bố cục bàn phím</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Ngày giờ</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>Chế độ 12 giờ</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>Chế độ 24 giờ</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Cài đặt thời gian</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Bạn có chắc chắn muốn làm trống mục %1 không?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Hủy</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Xóa</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Hành động này không thể được phục hồi</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Thiết bị không xác định</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Âm lượng không xác định</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Đĩa</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Mở</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Tháo tất cả</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Khởi chạy</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Chế độ Thời trang</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Chế độ Hiệu quả</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Trên đỉnh</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Dưới đáy</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Trái</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Phải</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Tiếp tục Hiển thị</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Tiếp tục Ẩn</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Ẩn Thông minh</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Chế độ</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Nơi chốn</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Tình trạng</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Kích thước</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Nhiều màn hình</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>Dạng thời trang</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>Dạng hiệu quả</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Chế độ</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Trên đỉnh</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Dưới đáy</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Trái</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Phải</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Nơi chốn</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Tiếp tục ẩn</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Ẩn thông minh</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Tình trạng</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Nhỏ</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Lớn</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Chế độ xem đa nhiệm</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Gỡ khỏi dock</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Cài đặt</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Năng lượng</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Thiết lập năng lượng</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Năng lượng %1, %2 còn lại</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Năng lượng %1, %2 giờ %3 phút còn lại</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Đang sạc %1, %2 phút sẽ đầy</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Đang sạc %1, %2 giờ %3 phút sẽ đầy</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Phù hợp %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Đang nạp %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Công suất 1%...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Công suất 1%, sạc đã đầy</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Dock</translation>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Hiện Trang chính</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Gỡ khỏi dock</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Năng lượng</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Tắt máy</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Dừng</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Ngủ đông</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Khóa</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Thoát ra</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Đổi tài khoản</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Thiết lập năng lượng</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Khởi động lại</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Thiết bị</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Mở tiếng</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Câm</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Cài đặt âm thanh</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Âm lượng %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Âm thanh</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Rác</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Rác - %1 tập tin</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Rác - %1 tập tin</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Mở</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Làm sạch</translation>
    </message>
</context>
</TS>
